<?php

/**
 * EDP Menu Page.
 *
 * @package designer-powerup-for-elementor\admin\pages
 *
 * phpcs:disable WordPress.Security.EscapeOutput.OutputNotEscaped
 * phpcs:disable WordPress.WP.I18n.MissingTranslatorsComment
 * phpcs:disable WordPress.Security.EscapeOutput.UnsafePrintingFunction
 */

$edp_user = pixify_edp_fs()->get_user();
$edp_fs_storage = FS_Storage::instance('plugin', 'elementor-designer-powerup');

$edp_current_time = time();

if (is_object($edp_user)) {
	// We have valid user data.
	$edp_user_name = ' ' . $edp_user->first;
} else {
	$edp_user = wp_get_current_user();
	$edp_user_name = '';
}

function get_contact_reply_expected_time_note() {

	$date = new DateTime('now', new DateTimeZone('Asia/Kolkata'));
	$timestamp = strtotime($date->format('Y-m-d'));
	$day = date('N', $timestamp);

	if ($day > 5) {
		// Saturday or Sunday
		return 'Expect a response by Monday.';
	}

	$hour = date('G', $timestamp);
	if (9 <= $hour && 17 > $hour) {
		// between 9am to 5pm
		return 'Expect a response within a couple hours.';
	} else if (0 < $hour && 9 < $hour) {
		// from midnight to 9am
		return 'Expect a response within 12 hours.';
	} else {
		// Late night or early morning
		return 'Expect a response within 18 hours.';
	}
}

/**
 * When enabled feature list is updated
 */
if (isset($_POST['update_settings'])) {
	// Check if current user has saved this.
	if (!current_user_can('manage_options')) {
		wp_die('Unauthorized user');
	}
	// Check for nonce from the form.
	if (!check_admin_referer('edp_addon_features_update', '_wpnonce')) {
		wp_die('Nonce verification failed');
	}

	// Show success notice
	echo '<div class="notice notice-success is-dismissible">
			<p>Settings Saved Successfully</p>
		</div>';

	$edp_addon_enabled_features = $_POST['edp_addon_enabled_features'];

	if ('' != $edp_addon_enabled_features) {
		$saved_features = [];
		foreach ($edp_addon_enabled_features as $feature_name => $val) {
			array_push($saved_features, $feature_name);
		}
		update_option('edp_addon_enabled_features', $saved_features);
	} else {
		update_option('edp_addon_enabled_features', Designer_Powerup_For_Elementor::get_default_features_setting());
	}
}

/**
 * Output features list controls
 */
function edp_addon_features_list() {
	$options = get_option('edp_addon_enabled_features', Designer_Powerup_For_Elementor::get_default_features_setting());
	$features_list = Designer_Powerup_For_Elementor::get_features_list();
	foreach ($features_list as $key => $feature_details) {
?>
		<div>
			<div class="feature-title-wrapper">
				<span class="feature-title"><?php echo $feature_details['title']; ?></span>
				<label class="switch">
					<input type="checkbox" id="edp_addon_features_list" name="edp_addon_enabled_features[<?php echo $key ?>]" value="1" <?php echo (in_array($key, $options)) ? 'checked' : ''; ?>>
					<span class="slider"></span>
				</label>
			</div>
			<div class="feature-desc">
				<?php echo $feature_details['desc']; ?>
			</div>
		</div>
<?php
	}
}

?>

<div class="wrap">

	<div class="edp-logo-wrapper">
		<img src="<?php echo esc_url(EDP_PLUGIN_URL); ?>admin/img/edp-logo.svg" alt="Designer Powerup for Elementor Logo" class="edp-logo">
	</div>

	<h2 class="nav-tab-wrapper">
		<a href="#" class="nav-tab nav-tab-active">Welcome</a>
	</h2>

	<div class="edp-help-page">

		<h1>Hello<?php echo $edp_user_name; ?>, thanks for installing the Designer Powerup addon.</h1>
		<span class="description">Your Elementor editor is now supercharged with Powerups. You can go ahead and start designing your pages.</span>

		<div class="edp-postbox-grid">

			<div class="postbox">

				<h2 class="hndle is-non-sortable">
					<img src="<?php echo esc_url(EDP_PLUGIN_URL); ?>admin/img/learn-features.svg" alt="Learn Features" class="learn-features">
					<span><?php _e('Getting Started', 'designer-powerup-for-elementor'); ?></span>
				</h2>

				<div class="inside">
					<p>
						<?php _e('Let\'s get you to know how to make the most out of the Designer Powerup features.', 'designer-powerup-for-elementor'); ?>
					</p>
					<p class="link-footer">
						<a href="<?php echo esc_url('https://pixify.net/kb/designer-powerup-for-elementor/?utm_source=plugin&utm_medium=link&utm_campaign=welcome_page'); ?>" target="_blank">
							<?php _e('Visit Knowledge Base', 'designer-powerup-for-elementor'); ?>
							<span aria-hidden="true" class="dashicons dashicons-external"></span>
						</a>
					</p>
				</div>

			</div>

			<div class="postbox">

				<h2 class="hndle is-non-sortable">
					<img src="<?php echo esc_url(EDP_PLUGIN_URL); ?>admin/img/get-help.svg" alt="Get Help" class="get-help">
					<span><?php _e('Need Help?', 'designer-powerup-for-elementor'); ?></span>
				</h2>

				<div class="inside">
					<p>
						<?php _e('Whether it\'s an error, issue or bug on your site, let me know and we\'ll solve it together.', 'designer-powerup-for-elementor'); ?>
						<span class="contact-resp-exp" title="I'm in the +0530 timezone">
							<?php echo get_contact_reply_expected_time_note(); ?>
						</span>
					</p>
					<p class="link-footer">
						<?php if (pixify_edp_fs()->is_whitelabeled()) : ?>
							<!-- Whitelabeled. Show direct mailto link -->
							<a href="mailto:paras@designerpowerup.com?subject=Need help with Designer Powerup addon" target="_blank">
								<?php _e('Contact', 'designer-powerup-for-elementor'); ?>
								<span aria-hidden="true" class="dashicons dashicons-external"></span>
							</a>
						<?php else : ?>
							<!-- Not whitelabeled. Link to the contact tab above -->
							<a href="<?php menu_page_url('designer_powerup_addon-contact') ?>">
								<?php _e('Contact', 'designer-powerup-for-elementor'); ?>
							</a>
						<?php endif; ?>
					</p>
				</div>
			</div>

			<div class="postbox">

				<h2 class="hndle is-non-sortable">
					<img src="<?php echo esc_url(EDP_PLUGIN_URL); ?>admin/img/manage-account.svg" alt="Manage Account" class="manage-account">
					<span><?php _e('Manage Account', 'designer-powerup-for-elementor'); ?></span>
				</h2>

				<div class="inside">
					<p>
						<?php
						printf(
							esc_html__('Info for this site is in the %1$s. For advanced management, login to your addon dashboard.', 'designer-powerup-for-elementor'),
							sprintf(
								'<a href="%s">%s</a>',
								menu_page_url('designer_powerup_addon-account', false),
								esc_html__('account tab', 'designer-powerup-for-elementor')
							)
						);
						?>
					</p>
					<p class="link-footer">
						<a href="<?php echo esc_url('https://pixify.net/account/?utm_source=plugin&utm_medium=link&utm_campaign=welcome_page'); ?>" target="_blank">
							<?php _e('Your addon dashboard', 'designer-powerup-for-elementor'); ?>
							<span aria-hidden="true" class="dashicons dashicons-external"></span>
						</a>
					</p>
				</div>

			</div>

		</div>

		<?php if ($edp_fs_storage->install_timestamp && ($edp_current_time - $edp_fs_storage->install_timestamp > 604800)) :
			// Show the note if 7 or more days have passed since the first installation of the plugin
		?>
			<div class="edp-cta-note">
				<a href="<?php echo esc_url('https://pixify.net/products/designer-powerup-for-elementor/submit-your-review/'); ?>" target="_blank">
					<b>Love Designer Powerup addon?</b> Leave a review here.
				</a>
			</div>
		<?php endif; ?>

		<hr>

		<div class="edp-postbox-grid">

			<!-- Features Toggle -->
			<div>
				<div class="postbox edp-features-toggle">

					<h2 class="hndle is-non-sortable size-lg">
						<span><?php _e('Toggle Features', 'designer-powerup-for-elementor'); ?></span>
					</h2>

					<div class="inside">

						<form method="post">

							<div class="feature-list">
								<?php edp_addon_features_list(); ?>
							</div>

							<input type="hidden" name="update_settings" value="Y" />
							<?php wp_nonce_field('edp_addon_features_update'); ?>
							<input name="submit" class="button button-primary" type="submit" value="<?php esc_attr_e('Save Settings'); ?>" />
						</form>

					</div>

				</div>
			</div>

			<!-- Changelog -->
			<div class="postbox edp-changelog-block">

				<h2 class="hndle is-non-sortable size-lg">
					<span><?php _e('Recent updates to the plugin', 'designer-powerup-for-elementor'); ?></span>
					<span class="link-header-right">
						<a href="<?php echo esc_url('https://pixify.net/kb/designer-powerup-for-elementor/general/changelog/'); ?>" target="_blank">
							<?php _e('View Full Changelog', 'designer-powerup-for-elementor'); ?>
							<span aria-hidden="true" class="dashicons dashicons-external"></span>
						</a>
					</span>
				</h2>

				<div class="inside changelog-list">

					<h4>2.3.3 - 30th Jan, 2024:</h4>
					<h5>Fixed</h5>
					<ul class="list--fix" title="Fix">
						<li>Old section flexbox and grid breaking with Elementor v3.19 update</li>
					</ul>
					<h5>Enhancement & Tweaks</h5>
					<ul class="list--enhancement" title="Tweak">
						<li>Freemius SDK Update</li>
					</ul>

					<h4>2.3.2 - 5th July, 2023:</h4>
					<h5>Enhancement & Tweaks</h5>
					<ul class="list--enhancement" title="Tweak">
						<li>Freemius SDK Update</li>
					</ul>

					<h4>2.3.1 - 24th May, 2023:</h4>
					<h5>Fixed</h5>
					<ul class="list--fix" title="Fix">
						<li>Shape Dividers custom color not working on Flexbox Containers</li>
					</ul>

					<h4>2.3.0 - 2nd December, 2022:</h4>
					<h5>Fixed</h5>
					<ul class="list--fix" title="Fix">
						<li>Grid item CSS not being outputted on frontend</li>
					</ul>

					<h4>2.2.9 - 30th November, 2022:</h4>
					<h5>Enhancement & Tweaks</h5>
					<ul class="list--enhancement" title="Tweak">
						<li>Compatibility of Quick Spacers and CSS Transforms with Flexbox Containers</li>
						<li>Freemius SDK Update</li>
					</ul>

					<h4>2.2.8 - 13th September, 2022:</h4>
					<h5>Fixed</h5>
					<ul class="list--fix" title="Fix">
						<li>Grid column conditional control not showing in editor</li>
						<li>PHP 8.0 deprecated warning fixed</li>
					</ul>
					<h5>Enhancement & Tweaks</h5>
					<ul class="list--enhancement" title="Tweak">
						<li>Updated minimum Elementor version to 3.1</li>
					</ul>

					<h4>v2.2.7 - 2nd March, 2022:</h4>
					<h5>Fixed</h5>
					<ul class="list--fix" title="Fix">
						<li>Security fix</li>
					</ul>

					<h4>v2.2.6 - 4th December, 2021:</h4>

					<h5>Fixed</h5>
					<ul class="list--fix" title="Fix">
						<li>Added Transition feature to the settings page list</li>
					</ul>

					<h4>v2.2.5 - 16th August, 2021:</h4>

					<h5>Enhancement & Tweaks</h5>
					<ul class="list--enhancement" title="Enhancement">
						<li>Compatibility with Elementor v3.4</li>
					</ul>
					<ul class="list--enhancement" title="Tweak">
						<li>Removed "Child Selector" option from CSS Transform feature</li>
						<li>Disabled CSS Transform feature by default for new installations</li>
					</ul>

					<h5>Fixed</h5>
					<ul class="list--fix" title="Fix">
						<li>Double spacer initialization on re-render and with Grid Layout enabled</li>
					</ul>

					<h4>v2.2.4 - 17th May, 2021:</h4>

					<h5>New</h5>
					<ul class="list--new" title="New">
						<li>Flexbox Wrap feature</li>
						<li>Ability to toggle powerups on/off from the settings page</li>
					</ul>

					<h5>Enhancement</h5>
					<ul class="list--enhancement" title="Enhancement">
						<li>Ability to change the Quick Spacers and Input Nudge jump value from the User Preferences panel</li>
						<li>Ability to partially enable Quick Spacers on only selected elements (section/column/widgets) from the User Preferences panel</li>
						<li>Performance improvements for the grid layout visual overlay. Now uses custom logic instead of ComputedStyleObserver library that caused occasional lag</li>
						<li>Updated the UI of the settings page</li>
						<li>Code and directory refactoring of helper JS functions</li>
						<li>Updated minimum Elementor version requirement to 3.0</li>
					</ul>

					<h5>Fixed</h5>
					<ul class="list--fix" title="Fix">
						<li>Trivial, non-breaking console errors changed to warnings</li>
					</ul>

					<h4>v2.2.3.1 - 18th April, 2021:</h4>

					<h5>Enhancement</h5>
					<ul class="list--enhancement" title="Enhancement">
						<li>Changed Quick Spacers max drag limit from 300px to 500px</li>
					</ul>

					<h5>Fixed</h5>
					<ul class="list--fix" title="Fix">
						<li>Blob Generator image not showing on Chromium browsers when Custom Positioning height is empty</li>
						<li>Flex section not stacking by default on mobile when the plugin is enabled</li>
						<li>Changed certain trivial console error notices to warnings</li>
					</ul>

					<h4>v2.2.3 - 1st March, 2021:</h4>

					<h5>Enhancement</h5>
					<ul class="list--enhancement" title="Enhancement">
						<li>Quick Spacers toggle shortcut "Ctrl+Q" now changed to "Opt/Alt + S"</li>
						<li>Increased section column count to 25</li>
						<li>All editing handles hidden when dragging the spacers</li>
						<li>Column borders thickened by a bit to improve visibility with Grid Visual Overlay enabled</li>
						<li>Extended blob image width and height control limits beyond 100%</li>
					</ul>

					<h5>Fixed</h5>
					<ul class="list--fix" title="Fix">
						<li>Infinite editor loading issue on new setups having Elementor v3.1+ with Optimized DOM enabled by default</li>
						<li>Grid Layout option dropdown for column unreadable in dark mode</li>
					</ul>

				</div>

			</div>

		</div>

	</div>

</div>
