var edpCustomDimensionsControl = elementor.modules.controls.Dimensions.extend({

	defaultDimensionValue: 1,

	initialize: function() {
		elementor.modules.controls.Dimensions.prototype.initialize.apply( this, arguments );
	},

	events: function() {
		return _.extend( elementor.modules.controls.Dimensions.prototype.events.apply( this, arguments ), {
			'click @ui.link': 'onLinkDimensionsClicked',
		});
	},

	/**
	 * Overwriting Elementor's Linking function
	 * @link: https://github.com/elementor/elementor/blob/master/assets/dev/js/editor/controls/dimensions.js#L145
	 *
	 * Note: For Elementor v3.4 and above, especially when Additional Breakpoints experiment is enabled, do not use the `parent_mode_values_on_link` param because it's hardcoded for only 3 traditional breakpoints
	 */
	onLinkDimensionsClicked: function( event ) {
		event.preventDefault();
		event.stopPropagation();

		this.ui.link.toggleClass( 'unlinked' );

		this.setValue( 'isLinked', ! this.ui.link.hasClass( 'unlinked' ) );

		if ( this.isLinkedDimensions() ) {

			// Set all controls value from the first control.
			this.ui.controls.val( this.ui.controls.eq( 0 ).val() );

		} else if ( this.model.get( 'parent_mode_values_on_link' ) ) {

			// This is a child responsive mode. Get values of parent control.
			// todo: fix the logic to accomodate for additional custom breakpoints system; make it dynamic instead of static hardcoding of breakpoints

			if ( '' === this.ui.controls.eq(0).val() ) {
				// Only continue if a value does not exist
				const currentControlID = this.model.get( 'name' ),
					mode = currentControlID.split( '_' ).pop(),
					parentControlName = currentControlID.replace( `_${mode}`, '' ),
					desktopVal = this.container.settings.get( parentControlName );

				if ( 'tablet' === mode ) {
					this.edpApplyParentSavedValue( desktopVal );
				} else {
					const tabletVal = this.container.settings.get( `${parentControlName}_tablet` ); // tablet value

					// Checking the "top" dimension because it's always there for all the EDP custom dimension controls
					const valueToOverride = ( '' !== tabletVal.top ) ? tabletVal : desktopVal;

					this.edpApplyParentSavedValue( valueToOverride );
				}
			}
		}

		this.updateDimensions();
	},

	/**
	 * Applying the value taken from the container settings to the input fields of the current control
	 * @link: https://github.com/elementor/elementor/blob/master/assets/dev/js/editor/controls/base-multiple.js#L6
	 */
	edpApplyParentSavedValue: function( values ) {
		$inputs = this.$( '[data-setting]' ),
			self = this;

		_.each( values, function( value, key ) {
			var $input = $inputs.filter( function() {
				return key === this.dataset.setting;
			} );

			self.setInputValue( $input, value );
		} );
	}

});

elementor.addControlView( 'edp-custom-dimensions', edpCustomDimensionsControl );
