<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Grid dimension control.
 *
 * A base control for creating dimension control. Displays input fields for top,
 * right, bottom, left and the option to link them together.
 *
 * @link: elementor/includes/controls/dimensions.php
 */
class Control_EDP_Grid_Dimensions extends \Elementor\Control_Base_Units {

	public function get_type() {
		return 'edp-custom-dimensions';
	}

	public function enqueue() {

		wp_register_style(
			'edp-custom-dimensions-control',
			EDP_PLUGIN_URL . 'custom-controls/edp-custom-dimensions/custom-dimensions.css',
			[],
			Designer_Powerup_For_Elementor::VERSION
		);

		wp_enqueue_style( 'edp-custom-dimensions-control' );

		wp_register_script(
			'edp-custom-dimensions-control',
			EDP_PLUGIN_URL . 'custom-controls/edp-custom-dimensions/custom-dimensions.js',
			[ 'jquery', 'elementor-editor' ],
			Designer_Powerup_For_Elementor::VERSION,
			true
		);

		wp_enqueue_script( 'edp-custom-dimensions-control' );
	}

	/**
	 * Get dimensions control default values.
	 *
	 * Retrieve the default value of the dimensions control. Used to return the
	 * default values while initializing the dimensions control.
	 *
	 * @return array Control default value.
	 */
	public function get_default_value() {
		return array_merge(
			parent::get_default_value(), [
				'top' => '',
				'right' => '',
				'bottom' => '',
				'left' => '',
				'isLinked' => true,
			]
		);
	}

	/**
	 * Get dimensions control default settings.
	 *
	 * Retrieve the default settings of the dimensions control. Used to return the
	 * default settings while initializing the dimensions control.
	 *
	 * @return array Control default settings.
	 */
	protected function get_default_settings() {
		return array_merge(
			parent::get_default_settings(), [
				'label_block' => true,
				'allowed_dimensions' => 'all',
				'placeholder' => '',
			]
		);
	}

	/**
	 * Render dimensions control output in the editor.
	 *
	 * Used to generate the control HTML in the editor using Underscore JS
	 * template. The variables for the class are available using `data` JS
	 * object.
	 */
	public function content_template() {
		$dimensions = [
			'top' => __( 'Top', 'elementor' ),
			'right' => __( 'Right', 'elementor' ),
			'bottom' => __( 'Bottom', 'elementor' ),
			'left' => __( 'Left', 'elementor' ),
		];
		?>
		<div class="elementor-control-field">
			<label class="elementor-control-title">{{{ data.label }}}</label>
			<?php $this->print_units_template(); ?>
			<div class="elementor-control-input-wrapper">
				<ul class="elementor-control-dimensions">
					<?php foreach ( $dimensions as $dimension_key => $dimension_title ) : ?>
						<# if ( -1 !== _.indexOf( allowed_dimensions, '<?php echo $dimension_key; ?>' ) ) { #>
							<li class="elementor-control-dimension">
								<input id="<?php $this->print_control_uid( $dimension_key ); ?>" type="number" data-setting="<?php echo esc_attr( $dimension_key ); ?>"
									placeholder="<#
									placeholder = view.getControlPlaceholder();
									if ( _.isObject( placeholder ) ) {
										if ( ! _.isUndefined( placeholder.<?php echo $dimension_key; ?> ) ) {
											print( placeholder.<?php echo $dimension_key; ?> );
										}
									} else {
									print( placeholder );
									} #>"
								/>
								<label for="<?php $this->print_control_uid( $dimension_key ); ?>" class="elementor-control-dimension-label">
									<# if ( _.isObject( data.dimension_labels ) ) {
										print( data.dimension_labels.<?php echo $dimension_key; ?> );
									} else { #>
										<?php echo $dimension_title; ?>
									<# } #>
								</label>
							</li>
						<# } #>
					<?php endforeach; ?>
					<li>
						<button class="elementor-link-dimensions tooltip-target" data-tooltip="<?php echo esc_attr__( 'Link values together', 'elementor' ); ?>">
							<span class="elementor-linked">
								<i class="eicon-link" aria-hidden="true"></i>
								<span class="elementor-screen-only"><?php echo esc_html__( 'Link values together', 'elementor' ); ?></span>
							</span>
							<span class="elementor-unlinked">
								<i class="eicon-chain-broken" aria-hidden="true"></i>
								<span class="elementor-screen-only"><?php echo esc_html__( 'Unlinked values', 'elementor' ); ?></span>
							</span>
						</button>
					</li>
				</ul>
			</div>
		</div>
		<# if ( data.description ) { #>
		<div class="elementor-control-field-description">{{{ data.description }}}</div>
		<# } #>
		<?php
	}
}
