<?php

/**
 * Blob Generator Initialization
 *
 * @package designer-powerup-for-elementor\powerups\blob
 * phpcs:disable WordPress.Security.EscapeOutput.OutputNotEscaped
 */

/**
 * Init Widget
 *
 * Include widgets files and register them
 */
add_action(
	'elementor/widgets/widgets_registered',
	function () {

		$is_elementor_above_v3_5 = version_compare(ELEMENTOR_VERSION, '3.5.0', '>=');

		// Include Widget files.
		require_once EDP_PLUGIN_PATH . 'powerups/blob/blob-widget.php';

		// Frontend Render.
		require_once EDP_PLUGIN_PATH . 'powerups/blob/render.php';

		// Register widget.
		if ($is_elementor_above_v3_5) {
			\Elementor\Plugin::instance()->widgets_manager->register(new \ED_Powerup_Blob_Generator_Widget());
		} else {
			// note: deprecated in v3.5 in favor of `register`
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type(new \ED_Powerup_Blob_Generator_Widget());
		}
	}
);

// Elementor Editor files.
add_action(
	'elementor/editor/after_enqueue_scripts',
	function () {

		wp_register_script(
			'edp-blob-lib',
			EDP_PLUGIN_URL . 'powerups/blob/lib/blob.js',
			[], // No dependency.
			self::VERSION,
			true
		);

		wp_enqueue_script(
			'edp-blob-render',
			EDP_PLUGIN_URL . 'powerups/blob/render.' . Designer_Powerup_For_Elementor::get_js_suffix() . '.js',
			['jquery', 'edp-blob-lib'],
			Designer_Powerup_For_Elementor::VERSION
		);

		wp_enqueue_style(
			'edp-blob-editor',
			EDP_PLUGIN_URL . 'powerups/blob/editor.min.css',
			['elementor-editor'],
			Designer_Powerup_For_Elementor::VERSION
		);
	}
);

add_action('elementor/frontend/after_enqueue_styles', 'edp_blob_overwrite_absolute_position_z_index');

/**
 * Resets absolute positioned z-index for blob generator
 *
 * @link: https://github.com/pixify/elementor-designer-powerup/issues/39
 */
function edp_blob_overwrite_absolute_position_z_index() {
	$custom_css =
		'.elementor-widget-edp-blob-generator.elementor-absolute {
		z-index: auto;
	}';

	wp_add_inline_style('elementor-frontend', $custom_css);
}
