<?php

namespace Designer_Powerup_For_Elementor;

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;

add_action('elementor/element/common/_section_style/after_section_start', function ($control_stack) {
	$breakpoints = array_reverse(array_keys(\Elementor\Plugin::$instance->breakpoints->get_active_breakpoints()));

	$auto_control_device_args = edp_cssg_positioning_generate_device_args($breakpoints, 'auto');
	$manual_control_device_args = edp_cssg_positioning_generate_device_args($breakpoints, 'manual');

	$control_stack->start_injection([
		'at' => 'before',
		'of' => '_margin'
	]);

	$control_stack->add_control(
		'edp_cssg_child',
		[
			'type' => Controls_Manager::HIDDEN,
			'default' => 'flex',
			'render_type' => 'ui',
			'style_transfer' => false,
		]
	);

	$control_stack->add_responsive_control(
		'edp_cssg_child_position_type',
		[
			'label' => __('Positioning', 'plugin-name'),
			'description' => __('Auto means no overlap of columns. Manual means full control over positioning with overlap. <b>Use only 1 of them at a time.</b>', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::CHOOSE,
			'options' => [
				'auto' => [
					'title' => __('Auto', 'plugin-name'),
					'icon' => 'eicon-section',
				],
				'manual' => [
					'title' => __('Manual', 'plugin-name'),
					'icon' => 'eicon-edit',
				],
			],
			'default' => 'auto',
			'style_transfer' => false,
			'toggle' => 'false',
			'render_type' => 'ui',
			'condition'     => [
				'edp_cssg_child' => 'grid',
			],
			'responsive' => true,
		]
	);

	$control_stack->add_responsive_control(
		'edp_cssg_child_position_auto',
		[
			'label'      => __('Auto', 'designer-powerup-for-elementor'),
			'description'  => __('Other columns will auto adjust', 'designer-powerup-for-elementor'),
			'type' => 'edp-custom-dimensions',
			'size_units' => [],
			'allowed_dimensions' => ['top', 'right'],
			'dimension_labels' => [
				'top' => 'Column Span',
				'right' => 'Row Span',
			],
			'style_transfer' => false,
			'condition' => [
				'edp_cssg_child' => 'grid',
				'edp_cssg_child_position_type' => 'auto',
			],
			'selectors' => [
				// row-start / col-start / row-end / col-end.
				'{{WRAPPER}}' => 'grid-area: span {{RIGHT}} / span {{TOP}} / span {{RIGHT}} / span {{TOP}};',
			],
			'device_args' => $auto_control_device_args,
			'responsive' => true,
		]
	);

	$control_stack->add_responsive_control(
		'edp_cssg_child_position_manual',
		[
			'label'      => __('Manual', 'designer-powerup-for-elementor'),
			'description'  => __('Custom grid child position. Will overlap other manually positioned columns.', 'designer-powerup-for-elementor'),
			'type' => 'edp-custom-dimensions',
			'size_units' => [],
			'dimension_labels' => [
				'top' => 'Col Start',
				'right' => 'Col Span',
				'bottom' => 'Row Start',
				'left' => 'Row Span',
			],
			'style_transfer' => false,
			'condition' => [
				'edp_cssg_child' => 'grid',
				'edp_cssg_child_position_type' => 'manual',
			],
			'selectors' => [
				// row-start / col-start / row-end / col-end.
				'{{WRAPPER}}' => 'grid-area: {{BOTTOM}} / {{TOP}} / span {{LEFT}} / span {{RIGHT}};',
			],
			'device_args' => $manual_control_device_args,
			'responsive' => true,
		]
	);

	$control_stack->end_injection();
});
