<?php

namespace Designer_Powerup_For_Elementor;

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

require_once EDP_PLUGIN_PATH . 'powerups/css-grid/controls/container-child.php';

use Elementor\Controls_Manager;

add_action('elementor/element/container/section_layout_container/after_section_start', function ($control_stack) {

	$control_stack->add_control(
		'edp_cssg_sec',
		[
			'label' => __('Layout', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::SELECT,
			'default' => 'flex',
			'description' => __('<b>Flexbox</b> is the default single row layout, and <b>Grid</b> is 2D layout using CSS Grid. <a href="https://youtu.be/9DsjLhBLReg" target="_blank">Here\'s how to use the Grid layout</a>.', 'designer-powerup-for-elementor'),
			'options' => [
				'flex'  => esc_html__('Flex', 'designer-powerup-for-elementor'),
				'grid' => esc_html__('Grid', 'designer-powerup-for-elementor'),
			],
			'selectors' => [
				'{{WRAPPER}}' => '--display: grid;',
			]
		]
	);

	$control_stack->add_control(
		'edp_cssg_sec_overlay',
		[
			'label'       => __('Show Grid Overlay', 'designer-powerup-for-elementor'),
			'description' => __('Real-time grid structure preview. Recommended to keep on when editing the grid.', 'designer-powerup-for-elementor'),
			'type'        => Controls_Manager::SWITCHER,
			'default'	  => 'yes',
			'render_type' => 'ui',
			'condition'     => [
				'edp_cssg_sec' => 'grid',
			],
		]
	);

	$control_stack->add_responsive_control(
		'edp_cssg_sec_gap',
		[
			'label'      => __('Grid Gap', 'designer-powerup-for-elementor'),
			'type' => 'edp-custom-dimensions',
			'size_units' => ['px', 'em', 'vh', 'vw'],
			'default' => [
				'unit' => 'px',
				'top' => 16,
				'right' => 16,
			],
			'allowed_dimensions' => ['top', 'right'],
			'dimension_labels' => [
				'top' => 'Column',
				'right' => 'Row',
			],
			'selectors' => [
				'{{WRAPPER}}' => '--gap: {{RIGHT}}{{UNIT}} {{TOP}}{{UNIT}};',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
			],
		]
	);

	$control_stack->add_control(
		'edp_cssg_sec_mode',
		[
			'label' => __('Grid Mode', 'designer-powerup-for-elementor'),
			'description' => __('Basic means equal height and width columns/rows. Advanced gives you full control over grid structure definition.', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::CHOOSE,
			'options' => [
				'basic' => [
					'title' => __('Basic', 'designer-powerup-for-elementor'),
					'icon' => 'eicon-column',
				],
				'advanced' => [
					'title' => __('Advanced', 'designer-powerup-for-elementor'),
					'icon' => 'eicon-inner-section',
				],
			],
			'default' => 'basic',
			'toggle' => false,
			'selectors'   => [
				// Set auto width on grid item columns
				// min width to disallow columns from overflowing
				'{{WRAPPER}}' . ' > .e-con-inner' => 'width: auto; min-width: 1px;',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
			],
		]
	);

	$control_stack->add_responsive_control(
		'edp_cssg_sec_template_basic_col',
		[
			'label' => __('Grid Columns', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::NUMBER,
			'min' => 1,
			'max' => 20,
			'default' => 3,
			'selectors' => [
				'{{WRAPPER}}' => 'grid-template-columns: repeat({{VALUE}}, 1fr);',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'basic',
			],
		]
	);

	$control_stack->add_responsive_control(
		'edp_cssg_sec_template_basic_row',
		[
			'label' => __('Grid Rows', 'designer-powerup-for-elementor'),
			'description' => __('Grid rows are of dynamic height and depends on the grid item\'s height and span', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::NUMBER,
			'min' => 1,
			'max' => 20,
			'default' => 2,
			'selectors' => [
				'{{WRAPPER}}' => 'grid-template-rows: repeat({{VALUE}}, 1fr);',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'basic',
			],
		]
	);

	$control_stack->add_responsive_control(
		'edp_cssg_sec_template_advanced_col',
		[
			'label'      => __('Grid Columns', 'designer-powerup-for-elementor'),
			'description' => __('Space separated column widths with units. <a href="https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-columns" target="_blank">Learn more</a>.', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::TEXT,
			'label_block' => true,
			'default' => '1fr 1fr',
			'selectors' => [
				'{{WRAPPER}}' => 'grid-template-columns: {{VALUE}};',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'advanced',
			],
		]
	);

	$control_stack->add_responsive_control(
		'edp_cssg_sec_template_advanced_row',
		[
			'label'      => __('Grid Rows', 'designer-powerup-for-elementor'),
			'description' => __('Space separated row widths with units. <a href="https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-rows" target="_blank">Learn more</a>.', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::TEXT,
			'label_block' => true,
			'default' => 'auto',
			'selectors' => [
				'{{WRAPPER}}' => 'grid-template-rows: {{VALUE}};',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'advanced',
			],
		]
	);

	$control_stack->add_control(
		'edp_cssg_sec_template_advanced_auto',
		[
			'label'     => __('Implicit item size', 'designer-powerup-for-elementor'),
			'type'      => Controls_Manager::POPOVER_TOGGLE,
			'render_type' => 'ui',
			'condition' => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'advanced',
			],
		]
	);

	$control_stack->start_popover();

	$control_stack->add_responsive_control(
		'edp_cssg_sec_template_advanced_auto_columns',
		[
			'label'      => __('Columns', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::TEXT,
			'label_block' => true,
			'default' => '1fr',
			'selectors' => [
				'{{WRAPPER}}' => 'grid-auto-columns: {{VALUE}};',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'advanced',
				'edp_cssg_sec_template_advanced_auto' => 'yes',
			],
		]
	);

	$control_stack->add_responsive_control(
		'edp_cssg_sec_template_advanced_auto_rows',
		[
			'label'      => __('Rows', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::TEXT,
			'label_block' => true,
			'default' => '1fr',
			'selectors' => [
				'{{WRAPPER}}' => 'grid-auto-rows: {{VALUE}};',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'advanced',
				'edp_cssg_sec_template_advanced_auto' => 'yes',
			],
		]
	);

	$control_stack->end_popover();

	$control_stack->add_control(
		'edp_cssg_sec_auto_template_description',
		[
			'raw' => __('Size of implicitly created grid items. Used when positioning is out of range of defined cells. Default <b>auto</b>.', 'elementor'),
			'type' => Controls_Manager::RAW_HTML,
			'content_classes' => 'elementor-descriptor',
			'condition' => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'advanced',
			],
		]
	);

	$control_stack->add_control(
		'edp_cssg_sec_divider',
		[
			'type'      => Controls_Manager::DIVIDER,
			'condition' => [
				'edp_cssg_sec' => 'grid',
			],
		]
	);
});
