<?php

if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;

add_action('elementor/element/section/section_layout/after_section_start', function ($control_stack) {

	// Legacy Selector, from versions before 3.0
	$section_selector = '.elementor-container > .elementor-row';

	$is_dom_optimization_enabled = (version_compare(ELEMENTOR_VERSION, '3.19', '>=')) ? true : Elementor\Plugin::$instance->experiments->is_feature_active('e_dom_optimization');

	if ($is_dom_optimization_enabled) {
		// DOM Optimization enabled, set the new section selector
		$section_selector = '.elementor-container';
	}

	$control_stack->add_control(
		'edp_cssg_sec',
		[
			'type' => Controls_Manager::SELECT,
			'label' => __('Layout', 'designer-powerup-for-elementor'),
			'description' => __('<b>Flexbox</b> is the default single row layout, and <b>Grid</b> is 2D layout using CSS Grid. <a href="https://youtu.be/9DsjLhBLReg" target="_blank">Here\'s how to use the Grid layout</a>.', 'designer-powerup-for-elementor'),
			'default' => 'flex',
			'options' => [
				'flex' => __('Flexbox', 'designer-powerup-for-elementor'),
				'grid'  => __('Grid', 'designer-powerup-for-elementor'),
			],
			'selectors' => [
				'{{WRAPPER}} > ' . $section_selector => 'display: {{VALUE}};',
			],
		]
	);

	$control_stack->add_control(
		'edp_cssg_sec_overlay',
		[
			'label'       => __('Show Grid Overlay', 'designer-powerup-for-elementor'),
			'description' => __('Real-time grid structure preview. Recommended to keep on when editing the grid.', 'designer-powerup-for-elementor'),
			'type'        => Controls_Manager::SWITCHER,
			'default'	  => 'yes',
			'render_type' => 'ui',
			'condition'     => [
				'edp_cssg_sec' => 'grid',
			],
		]
	);

	$control_stack->add_responsive_control(
		'edp_cssg_sec_gap',
		[
			'label'      => __('Grid Gap', 'designer-powerup-for-elementor'),
			'type' => 'edp-custom-dimensions',
			'size_units' => ['px', 'em', 'vh', 'vw'],
			'default' => [
				'unit' => 'px',
				'top' => 16,
				'right' => 16,
			],
			'allowed_dimensions' => ['top', 'right'],
			'dimension_labels' => [
				'top' => 'Column',
				'right' => 'Row',
			],
			'selectors' => [
				'{{WRAPPER}} > ' . $section_selector => 'grid-gap: {{RIGHT}}{{UNIT}} {{TOP}}{{UNIT}};',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
			],
		]
	);

	$control_stack->add_control(
		'edp_cssg_sec_mode',
		[
			'label' => __('Grid Mode', 'plugin-name'),
			'description' => __('Basic means equal height and width columns/rows. Advanced gives you full control over grid structure definition.', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::CHOOSE,
			'options' => [
				'basic' => [
					'title' => __('Basic', 'plugin-name'),
					'icon' => 'eicon-column',
				],
				'advanced' => [
					'title' => __('Advanced', 'plugin-name'),
					'icon' => 'eicon-inner-section',
				],
			],
			'default' => 'basic',
			'toggle' => false,
			'selectors'   => [
				// Set auto width on grid item columns
				// min width to disallow columns from overflowing
				'{{WRAPPER}} > ' . $section_selector . ' > .elementor-column' => 'width: auto; min-width: 1px;',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
			],
		]
	);

	$control_stack->add_responsive_control(
		'edp_cssg_sec_template_basic_col',
		[
			'label' => __('Grid Columns', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::NUMBER,
			'min' => 1,
			'max' => 20,
			'default' => 3,
			'selectors' => [
				'{{WRAPPER}} > ' . $section_selector => 'grid-template-columns: repeat({{VALUE}}, 1fr);',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'basic',
			],
		]
	);

	$control_stack->add_responsive_control(
		'edp_cssg_sec_template_basic_row',
		[
			'label' => __('Grid Rows', 'designer-powerup-for-elementor'),
			'description' => __('Grid rows are of dynamic height and depends on the grid item\'s height and span', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::NUMBER,
			'min' => 1,
			'max' => 20,
			'default' => 2,
			'selectors' => [
				'{{WRAPPER}} > ' . $section_selector => 'grid-template-rows: repeat({{VALUE}}, 1fr);',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'basic',
			],
		]
	);

	$control_stack->add_responsive_control(
		'edp_cssg_sec_template_advanced_col',
		[
			'label'      => __('Grid Columns', 'designer-powerup-for-elementor'),
			'description' => __('Space separated column widths with units. <a href="https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-columns" target="_blank">Learn more</a>.', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::TEXT,
			'label_block' => true,
			'default' => '1fr 1fr',
			'selectors' => [
				'{{WRAPPER}} > ' . $section_selector => 'grid-template-columns: {{VALUE}};',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'advanced',
			],
		]
	);

	$control_stack->add_responsive_control(
		'edp_cssg_sec_template_advanced_row',
		[
			'label'      => __('Grid Rows', 'designer-powerup-for-elementor'),
			'description' => __('Space separated row widths with units. <a href="https://developer.mozilla.org/en-US/docs/Web/CSS/grid-template-rows" target="_blank">Learn more</a>.', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::TEXT,
			'label_block' => true,
			'default' => 'auto',
			'selectors' => [
				'{{WRAPPER}} > ' . $section_selector => 'grid-template-rows: {{VALUE}};',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'advanced',
			],
		]
	);

	$control_stack->add_control(
		'edp_cssg_sec_template_advanced_auto',
		[
			'label'     => __('Implicit item size', 'designer-powerup-for-elementor'),
			'type'      => Controls_Manager::POPOVER_TOGGLE,
			'render_type' => 'ui',
			'condition' => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'advanced',
			],
		]
	);

	$control_stack->start_popover();

	$control_stack->add_responsive_control(
		'edp_cssg_sec_template_advanced_auto_columns',
		[
			'label'      => __('Columns', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::TEXT,
			'label_block' => true,
			'default' => '1fr',
			'selectors' => [
				'{{WRAPPER}} > ' . $section_selector => 'grid-auto-columns: {{VALUE}};',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'advanced',
				'edp_cssg_sec_template_advanced_auto' => 'yes',
			],
		]
	);

	$control_stack->add_responsive_control(
		'edp_cssg_sec_template_advanced_auto_rows',
		[
			'label'      => __('Rows', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::TEXT,
			'label_block' => true,
			'default' => '1fr',
			'selectors' => [
				'{{WRAPPER}} > ' . $section_selector => 'grid-auto-rows: {{VALUE}};',
			],
			'condition'     => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'advanced',
				'edp_cssg_sec_template_advanced_auto' => 'yes',
			],
		]
	);

	$control_stack->end_popover();

	$control_stack->add_control(
		'edp_cssg_sec_auto_template_description',
		[
			'raw' => __('Size of implicitly created grid items. Used when positioning is out of range of defined cells. Default <b>auto</b>.', 'elementor'),
			'type' => Controls_Manager::RAW_HTML,
			'content_classes' => 'elementor-descriptor',
			'condition' => [
				'edp_cssg_sec' => 'grid',
				'edp_cssg_sec_mode' => 'advanced',
			],
		]
	);

	$control_stack->add_control(
		'edp_cssg_sec_divider',
		[
			'type'      => Controls_Manager::DIVIDER,
			'condition' => [
				'edp_cssg_sec' => 'grid',
			],
		]
	);
});

add_action('elementor/element/section/section_layout/before_section_end', function ($control_stack) {
	/**
	 * Avoid Elementor from adding an :after elementor to .elementor-container as an IE11 fix
	 * That is because it messes up the grid layout
	 * @link: elementor/includes/elements/section.php:336
	 */
	$control_stack->update_responsive_control(
		'custom_height',
		[
			'selectors' => [
				'{{WRAPPER}} > .elementor-container' => 'min-height: {{SIZE}}{{UNIT}};',
				// '{{WRAPPER}} > .elementor-container:after' => 'content: ""; min-height: inherit;', // Hack for IE11
			],
		]
	);

	// showing the flex wrap only when flexbox is chosen
	$control_stack->update_control(
		'edp_section_flex_wrap',
		[
			'condition' => [
				'edp_cssg_sec' => 'flex',
			],
		]
	);
}, 11);  // late hook to execute after flex-wrap control gets added
