<?php
/**
 * CSS Opacity and Effects Controls.
 *
 * @package designer-powerup-for-elementor\powerups\controls
 */

use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Css_Filter;

/**
 * TODO: add blend mode option
 */

add_action(
	'elementor/element/after_section_end',
	function( $element, $section_id ) {

		if ( '_section_responsive' !== $section_id ) {
			return;
		}

		$widget_selector = ( $element->get_type() == 'widget' ) ? ' > .elementor-widget-container' : '';

		$element->start_controls_section(
			'edp_effects_section',
			[
				'label' => __( 'Filter Effects', 'designer-powerup-for-elementor' ),
				'tab'   => 'edp',
			]
		);

		$element->start_controls_tabs(
			'edp_effects_tabs'
		);

		$element->start_controls_tab(
			'edp_effects_normal_tab',
			[
				'label' => __( 'Normal', 'designer-powerup-for-elementor' ),
			]
		);

		$element->add_control(
			'edp_opacity_normal',
			[
				'label' => __( 'Opacity', 'designer-powerup-for-elementor' ),
				'type'  => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 1,
						'min' => 0.10,
						'step' => 0.01,
					],
				],
				'selectors' => [
					'{{WRAPPER}}' . $widget_selector => 'opacity: {{SIZE}};',
				],
			]
		);

		$element->add_group_control(
			Group_Control_Css_Filter::get_type(),
			[
				'name'     => 'edp_css_filters_normal',
				'selector' => '{{WRAPPER}}' . $widget_selector,
			]
		);

		$element->end_controls_tab();

		/**
		 * Effects Hover State
		 */

		$element->start_controls_tab(
			'edp_effects_hover_tab',
			[
				'label' => __( 'Hover', 'designer-powerup-for-elementor' ),
			]
		);

		$element->add_control(
			'edp_opacity_hover',
			[
				'label' => __( 'Opacity', 'designer-powerup-for-elementor' ),
				'type'  => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max'  => 1,
						'min'  => 0.10,
						'step' => 0.01,
					],
				],
				'selectors' => [
					'{{WRAPPER}}' . $widget_selector . ':hover' => 'opacity: {{SIZE}};',
				],
			]
		);

		// CSS Filters.
		$element->add_group_control(
			Group_Control_Css_Filter::get_type(),
			[
				'name'     => 'edp_css_filters_hover',
				'selector' => '{{WRAPPER}}' . $widget_selector . ':hover',
			]
		);

		$element->end_controls_tab();

		$element->end_controls_tabs();

		$element->add_control(
			'edp_effects_saturation_note',
			[
				'raw'             => __( 'Saturation only applies to images', 'designer-powerup-for-elementor' ),
				'type'            => Controls_Manager::RAW_HTML,
				'content_classes' => 'elementor-control-field-description',
				'render_type'     => 'none',
			]
		);

		$element->end_controls_section();

	},
	10,
	2
);
