<?php
/**
 * Multi-colored Gradient controls
 *
 * @package designer-powerup-for-elementor/powerups/gradient
 */

use \Elementor\Element_Base;
use \Elementor\Controls_Stack;
use \Elementor\Controls_Manager;
use \Elementor\Repeater;

add_action( 'elementor/element/after_section_end', 'edp_advanced_gradient_powerup_controls', 10, 2 );
function edp_advanced_gradient_powerup_controls( Controls_Stack $element, $section_id ) {

	if ( ! $element instanceof Element_Base ) {
		return;
	}

	if ( '_section_responsive' !== $section_id ) {
		return;
	}

	$element->start_controls_section(
		'edp_gradient_section',
		[
			'label' => __( 'Advanced Gradient', 'designer-powerup-for-elementor' ),
			'tab'   => 'edp',
		]
	);

	$element->add_control(
		'edp_gradient_apply_on_child',
		[
			'label'       => __( 'Apply on Child Element?', 'designer-powerup-for-elementor' ),
			'type'        => Controls_Manager::SWITCHER,
			'render_type' => 'ui',
		]
	);

	$element->add_control(
		'edp_gradient_apply_on_child_class',
		[
			'label'       => __( 'Child Selector', 'designer-powerup-for-elementor' ),
			'type'        => Controls_Manager::TEXT,
			'placeholder' => __( '.child-selector', 'designer-powerup-for-elementor' ),
			'condition'   => [
				'edp_gradient_apply_on_child' => 'yes',
			],
			'render_type' => 'ui',
		]
	);

	$element->add_control(
		'edp_gradient_fill',
		[
			'label'   => __( 'Apply Gradient On', 'designer-powerup-for-elementor' ),
			'type'    => Controls_Manager::SELECT,
			'default' => 'background',
			'options' => [
				'background' => __( 'Background', 'designer-powerup-for-elementor' ),
				'text'       => __( 'Text', 'designer-powerup-for-elementor' ),
			],
			'render_type' => 'ui',
		]
	);

	$element->add_control(
		'edp_gradient_divider',
		[
			'type' => Controls_Manager::DIVIDER,
		]
	);

	$repeater = new Repeater();

	$repeater->add_control(
		'edp_gradient_color',
		[
			'label'  => __( 'Color', 'designer-powerup-for-elementor' ),
			'type'   => Controls_Manager::COLOR,
			'render_type' => 'ui',
		]
	);

	$repeater->add_control(
		'edp_gradient_location',
		[
			'label'      => __( 'Location (%)', 'designer-powerup-for-elementor' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ '%' ],
			'range' => [
				'%' => [
					'min' => -100,
					'max' => 100,
				],
			],
			'default'    => [
				'unit' => '%',
				'size' => 0,
			],
			'render_type' => 'ui',
		]
	);

	$element->add_control(
		'edp_gradient',
		[
			'label'          => __( 'Gradient Colors', 'designer-powerup-for-elementor' ),
			'type'           => Controls_Manager::REPEATER,
			'fields'         => $repeater->get_controls(),
			'prevent_empty'  => false,
			'style_transfer' => false,
			'title_field'    =>
				'<span class="edp-control-color-swatch" style="background-color: {{{ typeof __globals__ !== "undefined" ? elementor.helpers.edpGetGlobalColorValue( __globals__, edp_gradient_color, "edp_gradient_color" ) : edp_gradient_color }}};"></span>
				@ {{{ edp_gradient_location.size }}}%',
		]
	);

	$element->add_control(
		'edp_gradient_type',
		[
			'label'     => __( 'Type', 'designer-powerup-for-elementor' ),
			'type'      => Controls_Manager::SELECT,
			'default'   => 'linear',
			'separator' => 'before',
			'options'   => [
				'linear' => __( 'Linear', 'designer-powerup-for-elementor' ),
				'radial' => __( 'Radial', 'designer-powerup-for-elementor' ),
			],
			'render_type' => 'ui',
		]
	);

	$element->add_control(
		'edp_linear_gradient_angle',
		[
			'label'      => __( 'Angle', 'designer-powerup-for-elementor' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'deg' ],
			'range'      => [
				'deg' => [
					'min'  => 0,
					'max'  => 360,
					'step' => 5,
				],
			],
			'default'   => [
				'unit' => 'deg',
				'size' => 180,
			],
			'condition' => [
				'edp_gradient_type' => 'linear',
			],
			'render_type' => 'ui',
		]
	);

	$element->add_control(
		'edp_radial_gradient_position',
		[
			'label'   => __( 'Position', 'designer-powerup-for-elementor' ),
			'type'    => Controls_Manager::SELECT,
			'default' => 'center center',
			'options' => [
				'center center' => __( 'Center Center', 'designer-powerup-for-elementor' ),
				'center left'   => __( 'Center Left', 'designer-powerup-for-elementor' ),
				'center right'  => __( 'Center Right', 'designer-powerup-for-elementor' ),
				'top center'    => __( 'Top Center', 'designer-powerup-for-elementor' ),
				'top left'      => __( 'Top Left', 'designer-powerup-for-elementor' ),
				'top right'     => __( 'Top Right', 'designer-powerup-for-elementor' ),
				'bottom center' => __( 'Bottom Center', 'designer-powerup-for-elementor' ),
				'bottom left'   => __( 'Bottom Left', 'designer-powerup-for-elementor' ),
				'bottom right'  => __( 'Bottom Right', 'designer-powerup-for-elementor' ),
			],
			'condition' => [
				'edp_gradient_type' => 'radial',
			],
			'render_type' => 'ui',
		]
	);

	$element->end_controls_section();
}

/**
 * Remove the repeaters from Elementor Pro form field section
 * Fixes an issue where these repeaters are included as a part of form fields repeater control not displaying the text fields
 */
add_action( 'elementor/element/form/section_form_fields/before_section_start', function() {
	remove_action( 'elementor/element/after_section_end', 'edp_advanced_gradient_powerup_controls', 10 );
});
