<?php
/**
 * Frontend render
 *
 * @package designer-powerup-for-elementor\powerups\gradient
 */

use Elementor\Core\DynamicTags\Dynamic_CSS;

/**
 * Hooks into frontend CSS processing to add the Gradient CSS.
 * Inspired from the implementation of Custom CSS in Elementor Pro.
 *
 * @source elementor-pro/modules/custom-css/module.php#L48
 */
add_action(
	'elementor/element/parse_css',
	function( $post_css, $element ) {

		if ( $post_css instanceof Dynamic_CSS ) {
			return;
		}

		$settings = $element->get_settings_for_display();

		if ( ! $settings['edp_gradient'] ) {
			return;
		}

		$child_selector = ( 'yes' === $settings['edp_gradient_apply_on_child'] ) ? ' ' . $settings['edp_gradient_apply_on_child_class'] : '';
		$gradient_array = [];

		// Only output the child widget selector if the element is a widget.
		$widget_selector = ( $element->get_type() == 'widget' ) ? ' > .elementor-widget-container' : '';

		$gradient_position = ( 'linear' == $settings['edp_gradient_type'] ) ? $settings['edp_linear_gradient_angle']['size'] . 'deg' : 'at ' . $settings['edp_radial_gradient_position'];

		foreach ( $settings['edp_gradient'] as $i => $item ) {

			$gradient_color = $item['edp_gradient_color'];

			if ( isset( $item['__globals__'] ) && $item['__globals__']['edp_gradient_color'] ) {
				$global_color_id = explode( '=', $item['__globals__']['edp_gradient_color'], 2 )[1];
				$gradient_color = "var(--e-global-color-{$global_color_id})";
			}

			$gradient_array[ $i ] = $gradient_color . ' ' . $item['edp_gradient_location']['size'] . '%';
		}

		$the_gradient = implode( ', ', $gradient_array );

		$gradient_css = $post_css->get_element_unique_selector( $element ) . $widget_selector . $child_selector . ' { ';
			$gradient_css .= 'background: ' . $settings['edp_gradient_type'] . '-gradient( ';
				$gradient_css .= $gradient_position . ', ' . $the_gradient;
			$gradient_css .= '); ';
			if ( 'text' === $settings['edp_gradient_fill'] ) {
				$gradient_css .= '-webkit-background-clip: text; -webkit-text-fill-color: transparent;';
			}
		$gradient_css .= '}';

		$post_css->get_stylesheet()->add_raw_css( $gradient_css );
	},
	10, 2
);
