<?php
/**
 * Page Grid Controls
 *
 * @package designer-powerup-for-elementor\powerups\page-grid
 */

use \Elementor\Controls_Manager;

add_action( 'elementor/element/editor-preferences/preferences/after_section_end', 'edp_page_grid_controls' );

/**
 * Adds Page Grid controls to User preferences global option.
 *
 * @param Object $stack User Preferences page's control stack.
 */
function edp_page_grid_controls( $stack ) {

	$stack->start_controls_section(
		'edp_page_grid_section',
		[
			'label' => __( 'Page Grid', 'designer-powerup-for-elementor' ),
			'tab'   => Controls_Manager::TAB_SETTINGS,
		]
	);

	$stack->add_control(
		'edp_page_grid_keyboard_toggle_note',
		[
			'raw'             => __( 'Use "<b>Cmd/Ctrl + G</b>" to toggle Grid', 'designer-powerup-for-elementor' ),
			'type'            => Controls_Manager::RAW_HTML,
			'content_classes' => 'elementor-panel-alert elementor-panel-alert-success',
			'render_type'     => 'none',
		]
	);

	$stack->add_control(
		'edp_page_grid',
		[
			'label'     => __( 'Page Grid', 'designer-powerup-for-elementor' ),
			'type'      => Controls_Manager::SWITCHER,
			'label_on'  => __( 'Show', 'designer-powerup-for-elementor' ),
			'label_off' => __( 'Hide', 'designer-powerup-for-elementor' ),
			'selectors' => [
				// frontend CSS adds display:none for body::before in Canvas mode.
				"body.elementor-page::before" => 'content: ""; display: block !important;',
			],
		]
	);

	$stack->add_responsive_control(
		'edp_page_grid_max_width',
		[
			'label'      => __( 'Max Width', 'designer-powerup-for-elementor' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'range'      => [
				'px' => [
					'min'  => 0,
					'max'  => 3000,
					'step' => 1,
				],
				'%' => [
					'min'  => 0,
					'max'  => 100,
					'step' => 0.1,
				],
			],
			'default'     => [
				'unit' => 'px',
				'size' => 1140,
			],
			'condition'   => [
				'edp_page_grid' => 'yes',
			],
			'selectors' => [
				"body.elementor-page" => '--edp_page_grid_max_width: {{SIZE}}{{UNIT}};',
			],
		]
	);

	$stack->add_responsive_control(
		'edp_page_grid_offset',
		[
			'label'       => __( 'Offset', 'designer-powerup-for-elementor' ),
			'description' => __( 'Space at both ends of the grid', 'designer-powerup-for-elementor' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ 'px', 'em', '%' ],
			'range'       => [
				'px' => [
					'min'  => 0,
					'max'  => 1000,
					'step' => 1,
				],
				'em' => [
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				],
				'%' => [
					'min'  => 0,
					'max'  => 100,
					'step' => 0.1,
				],
			],
			'default'     => [
				'unit' => 'px',
				'size' => 0,
			],
			'condition'   => [
				'edp_page_grid' => 'yes',
			],
			'selectors' => [
				"body.elementor-page" => '--edp_page_grid_offset: {{SIZE}}{{UNIT}};',
			],
		]
	);

	$stack->add_responsive_control(
		'edp_page_grid_columns',
		[
			'label'       => __( 'Columns', 'designer-powerup-for-elementor' ),
			'type'        => Controls_Manager::NUMBER,
			'min'         => 1,
			'max'         => 100,
			'step'        => 1,
			'default'     => 12,
			'condition'   => [
				'edp_page_grid' => 'yes',
			],
			'selectors' => [
				"body.elementor-page" => '--edp_page_grid_columns: {{VALUE}};',
			],
		]
	);

	$stack->add_responsive_control(
		'edp_page_grid_gutter',
		[
			'label'       => __( 'Gutter', 'designer-powerup-for-elementor' ),
			'description' => __( 'Space between the columns', 'designer-powerup-for-elementor' ),
			'type'        => Controls_Manager::SLIDER,
			'size_units'  => [ 'px', 'em', '%' ],
			'range'       => [
				'px' => [
					'min'  => 0,
					'max'  => 200,
					'step' => 1,
				],
				'em' => [
					'min'  => 0,
					'max'  => 20,
					'step' => 1,
				],
				'%' => [
					'min'  => 0,
					'max'  => 100,
					'step' => 0.1,
				],
			],
			'default' => [
				'unit' => 'px',
				'size' => 16,
			],
			'condition' => [
				'edp_page_grid' => 'yes',
			],
			'selectors' => [
				"body.elementor-page" => '--edp_page_grid_gutter: {{SIZE}}{{UNIT}};',
			],
		]
	);

	$stack->add_control(
		'edp_page_grid_color',
		[
			'label'       => __( 'Grid Color', 'designer-powerup-for-elementor' ),
			'type'        => Controls_Manager::COLOR,
			'default'     => 'rgba(0,255,255,0.25)',
			'condition'   => [
				'edp_page_grid' => 'yes',
			],
			'selectors'	=> [
				"body.elementor-page" => '--edp_page_grid_color: {{VALUE}};',
			],
		]
	);

	$stack->end_controls_section();

}
