<?php
/**
 * Multi-Layered Shadow Controls.
 *
 * @package designer-powerup-for-elementor\powerups\shadow
 */

use Elementor\Controls_Manager;
use Elementor\Repeater;

add_action( 'elementor/element/after_section_end', 'edp_layered_shadow_powerup_controls', 10, 2 );
function edp_layered_shadow_powerup_controls( $element, $section_id ) {

	if ( '_section_responsive' !== $section_id ) {
		return;
	}

	$element->start_controls_section(
		'edp_shadow_section',
		[
			'label' => __( 'Layered Shadow', 'designer-powerup-for-elementor' ),
			'tab'   => 'edp',
		]
	);

	$element->add_control(
		'edp_shadow_apply_on_child',
		[
			'label'       => __( 'Apply on Child Element?', 'designer-powerup-for-elementor' ),
			'type'        => Controls_Manager::SWITCHER,
			'render_type' => 'ui',
		]
	);

	$element->add_control(
		'edp_shadow_apply_on_child_class',
		[
			'label'       => __( 'Child Selector', 'designer-powerup-for-elementor' ),
			'type'        => Controls_Manager::TEXT,
			'placeholder' => __( '.child-selector', 'designer-powerup-for-elementor' ),
			'condition'   => [
				'edp_shadow_apply_on_child' => 'yes',
			],
			'render_type' => 'ui',
		]
	);

	$element->add_control(
		'edp_shadow_fill',
		[
			'label'   => __( 'Apply Shadow On', 'designer-powerup-for-elementor' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => 'box',
			'options' => [
				'box'  => __( 'Block', 'designer-powerup-for-elementor' ),
				'text' => __( 'Text', 'designer-powerup-for-elementor' ),
			],
			'render_type' => 'ui',
		]
	);

	$element->add_control(
		'edp_shadow_divider',
		[
			'type' => Controls_Manager::DIVIDER,
		]
	);

	$element->start_controls_tabs(
		'edp_shadow_tabs'
	);

	$element->start_controls_tab(
		'edp_shadow_normal_tab',
		[
			'label' => __( 'Normal', 'designer-powerup-for-elementor' ),
		]
	);

	$repeater_normal_control_defaults = [
		'horizontal' => 0,
		'vertical' => 2,
		'blur' => 4,
		'color' => 'rgba(0,0,0,0.13)',
	];
	$repeater_normal = edp_layered_shadow_repeater_controls( $element, $repeater_normal_control_defaults, 'normal' );

	$element->add_control(
		'edp_shadow_normal',
		[
			'label'          => __( 'Shadow Layers', 'designer-powerup-for-elementor' ),
			'type'           => Controls_Manager::REPEATER,
			'fields'         => $repeater_normal->get_controls(),
			'prevent_empty'  => false,
			'style_transfer' => false,
			'title_field'    => '<span class="edp-control-color-swatch type--shadow" style="box-shadow: {{ edp_shadow_horizontal_normal.size }}px {{ edp_shadow_vertical_normal.size }}px {{ edp_shadow_blur_normal.size }}px {{ edp_shadow_spread_normal.size }}px {{ edp_shadow_color_normal }} {{ edp_shadow_position_normal }};"></span>
				{{ edp_shadow_horizontal_normal.size }}px {{ edp_shadow_vertical_normal.size }}px {{ edp_shadow_blur_normal.size }}px {{ edp_shadow_spread_normal.size }}px
				<span class="edp-control-color-swatch" style="background-color: {{{ typeof __globals__ !== "undefined" ? elementor.helpers.edpGetGlobalColorValue( __globals__, edp_shadow_color_normal, "edp_shadow_color_normal" ) : edp_shadow_color_normal }}};"></span>
				{{ edp_shadow_position_normal }}',
		]
	);

	$element->end_controls_tab();

	/**
	 * Shadow Hover State
	 */

	$element->start_controls_tab(
		'edp_shadow_hover_tab',
		[
			'label' => __( 'Hover', 'designer-powerup-for-elementor' ),
		]
	);

	$repeater_hover_control_defaults = [
		'horizontal' => 0,
		'vertical' => 4,
		'blur' => 12,
		'color' => 'rgba(0,0,0,0.13)',
	];
	$repeater_hover = edp_layered_shadow_repeater_controls( $element, $repeater_hover_control_defaults, 'hover' );

	$element->add_control(
		'edp_shadow_hover',
		[
			'label'          => __( 'Shadow Layers', 'designer-powerup-for-elementor' ),
			'type'           => Controls_Manager::REPEATER,
			'fields'         => $repeater_hover->get_controls(),
			'prevent_empty'  => false,
			'style_transfer' => false,
			'title_field'    => '<span class="edp-control-color-swatch type--shadow" style="box-shadow: {{ edp_shadow_horizontal_hover.size }}px {{ edp_shadow_vertical_hover.size }}px {{ edp_shadow_blur_hover.size }}px {{ edp_shadow_spread_hover.size }}px {{ edp_shadow_color_hover }} {{ edp_shadow_position_hover }};"></span>
				{{ edp_shadow_horizontal_hover.size }}px {{ edp_shadow_vertical_hover.size }}px {{ edp_shadow_blur_hover.size }}px {{ edp_shadow_spread_hover.size }}px
				<span class="edp-control-color-swatch" style="background-color: {{{ typeof __globals__ !== "undefined" ? elementor.helpers.edpGetGlobalColorValue( __globals__, edp_shadow_color_hover, "edp_shadow_color_hover" ) : edp_shadow_color_hover }}};"></span>
				{{ edp_shadow_position_hover }}',
		]
	);

	$element->end_controls_tab();

	$element->end_controls_tabs();

	$element->end_controls_section();

}

function edp_layered_shadow_repeater_controls( $el, $defaults, $state = 'normal' ) {

	$repeater = new Repeater();

	$repeater->add_control(
		'edp_shadow_horizontal_' . $state,
		[
			'label'      => __( 'Horizontal', 'designer-powerup-for-elementor' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range'      => [
				'px' => [
					'min'  => -100,
					'max'  => 100,
					'step' => 1,
				],
			],
			'default' => [
				'unit' => 'px',
				'size' => $defaults['horizontal'],
			],
			'render_type' => 'ui',
		]
	);

	$repeater->add_control(
		'edp_shadow_vertical_' . $state,
		[
			'label'      => __( 'Vertical', 'designer-powerup-for-elementor' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range'      => [
				'px' => [
					'min'  => -100,
					'max'  => 100,
					'step' => 1,
				],
			],
			'default' => [
				'unit' => 'px',
				'size' => $defaults['vertical'],
			],
			'render_type' => 'ui',
		]
	);

	$repeater->add_control(
		'edp_shadow_blur_' . $state,
		[
			'label'      => __( 'Blur', 'designer-powerup-for-elementor' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range'      => [
				'px' => [
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				],
			],
			'default' => [
				'unit' => 'px',
				'size' => $defaults['blur'],
			],
			'render_type' => 'ui',
		]
	);

	$repeater->add_control(
		'edp_shadow_spread_' . $state,
		[
			'label'      => __( 'Spread', 'designer-powerup-for-elementor' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range'      => [
				'px' => [
					'min'  => -100,
					'max'  => 100,
					'step' => 1,
				],
			],
			'default' => [
				'unit' => 'px',
				'size' => 0,
			],
			'render_type' => 'ui',
		]
	);

	$repeater->add_control(
		'edp_shadow_color_' . $state,
		[
			'label'  => __( 'Color', 'designer-powerup-for-elementor' ),
			'type'   => Controls_Manager::COLOR,
			'default' => $defaults['color'],
			'render_type' => 'ui',
		]
	);

	$repeater->add_control(
		'edp_shadow_position_' . $state,
		[
			'label'   => _x( 'Position', 'Box Shadow Control', 'designer-powerup-for-elementor' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				' '     => _x( 'Out', 'Box Shadow Control', 'designer-powerup-for-elementor' ),
				'inset' => _x( 'In', 'Box Shadow Control', 'designer-powerup-for-elementor' ),
			],
			'default' => ' ',
			'render_type' => 'ui',
		]
	);

	return $repeater;

}

/**
 * Remove the repeaters from Elementor Pro form field section
 * Fixes an issue where these repeaters are included as a part of form fields repeater control not displaying the text fields
 */
add_action( 'elementor/element/form/section_form_fields/before_section_start', function() {
	remove_action( 'elementor/element/after_section_end', 'edp_layered_shadow_powerup_controls', 10 );
});
