<?php
/**
 * Rendering the Multi-Layered Shadows.
 *
 * @package designer-powerup-for-elementor\powerups\shadow
 */

use Elementor\Core\DynamicTags\Dynamic_CSS;

/**
 * Hooks into frontend CSS processing to add the Gradient CSS.
 * Inspired from the implementation of Custom CSS in Elementor Pro.
 *
 * @source elementor-pro/modules/custom-css/module.php#L48
 */
add_action(
	'elementor/element/parse_css',
	function( $post_css, $element ) {

		if ( $post_css instanceof Dynamic_CSS ) {
			return;
		}

		$settings = $element->get_settings_for_display();

		if ( ! $settings || ( ! $settings['edp_shadow_normal'] && ! $settings['edp_shadow_hover'] ) ) {
			return;
		}

		// Only output the widget container selector if the element is a widget.
		$widget_selector = ( $element->get_type() == 'widget' ) ? ' > .elementor-widget-container' : '';

		$box_shadow_css = '';

		$shadow_states = [ 'normal', 'hover' ];

		$is_box_shadow = ( 'box' === $settings[ 'edp_shadow_fill' ] );

		foreach ( $shadow_states as $state_key => $state ) {

			if ( $settings[ 'edp_shadow_' . $state ] ) {

				$child_selector = ( 'yes' === $settings['edp_shadow_apply_on_child'] ) ? ' ' . $settings['edp_shadow_apply_on_child_class'] : '';

				$shadow_length = count( $settings[ 'edp_shadow_' . $state ] );
				$shadow_loop_counter = 1;

				if ( 'hover' == $state ) {
					$box_shadow_css .= '@media (any-hover: hover) {'; // @media start.
				}

				$box_shadow_css .= $post_css->get_element_unique_selector( $element ) . $widget_selector . $child_selector;

				if ( 'hover' == $state ) {
					$box_shadow_css .= ':hover';
				}

				if ( $is_box_shadow ) {
					$box_shadow_css .= ' { box-shadow: ';
				} else {
					$box_shadow_css .= ' { text-shadow: ';
				}

				foreach ( $settings[ 'edp_shadow_' . $state ] as $item ) {

					$box_shadow_css .= $item[ 'edp_shadow_horizontal_' . $state ]['size'] . 'px ';
					$box_shadow_css .= $item[ 'edp_shadow_vertical_' . $state ]['size'] . 'px ';
					$box_shadow_css .= $item[ 'edp_shadow_blur_' . $state ]['size'] . 'px ';

					if ( $is_box_shadow ) {
						$box_shadow_css .= $item[ 'edp_shadow_spread_' . $state ]['size'] . 'px ';
					}

					$shadow_color = $item[ 'edp_shadow_color_' . $state ];

					if ( isset( $item['__globals__'] ) && $item['__globals__'][ 'edp_shadow_color_' . $state ] ) {
						$global_color_id = explode( '=', $item['__globals__'][ 'edp_shadow_color_' . $state ], 2 )[1];
						$shadow_color = "var(--e-global-color-{$global_color_id})";
					}

					$box_shadow_css .= $shadow_color;

					if ( $is_box_shadow && 'inset' === $item[ 'edp_shadow_position_' . $state ] ) {
						$box_shadow_css .= ' inset';
					}

					if ( $shadow_loop_counter != $shadow_length ) {
						$box_shadow_css .= ', ';
					}

					$shadow_loop_counter++;

				}

				$box_shadow_css .= '}';

				if ( 'hover' == $state ) {
					$box_shadow_css .= '}'; // @media end.
				}
			}
		}

		$post_css->get_stylesheet()->add_raw_css( $box_shadow_css );
	},
	10, 2
);
