<?php

/**
 * CSS Transform Controls.
 *
 * @package designer-powerup-for-elementor\powerups\transform
 */

use \Elementor\Controls_Manager;

add_action(
	'elementor/element/after_section_end',
	function ($element, $section_id) {

		if ('_section_responsive' !== $section_id) {
			return;
		}

		$element_selector = ('widget' === $element->get_type()) ? ' > .elementor-widget-container' : '';

		$element->start_controls_section(
			'edp_transform_section',
			[
				'label' => __('3D Transforms', 'designer-powerup-for-elementor'),
				'tab'   => 'edp',
			]
		);

		/**
		 * Note: Transform - Motion Effects incompatibility notice. Only on Pro version.
		 */
		if (defined('ELEMENTOR_PRO_VERSION')) {
			$element->add_control(
				'edp_transform_motion_effect_note',
				[
					'raw'             => __('Transformations don\'t work when Motion Effects are on.', 'designer-powerup-for-elementor'),
					'type'            => Controls_Manager::RAW_HTML,
					'content_classes' => 'elementor-control-field-description',
					'render_type'     => 'none',
				]
			);
		}

		$element->add_responsive_control(
			'edp_transform_perspective',
			[
				'label' => __('3D Perspective', 'designer-powerup-for-elementor'),
				'type'  => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min'  => 1,
						'max'  => 3000,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}}' => 'perspective: {{SIZE}}{{UNIT}};',
				],
			]
		);

		// Note: Had to expire Apply on Child element to make the whole system CSS based to make it compatible with Additional Breakpoints on v3.4+
		// $element->add_control(
		// 	'edp_transform_apply_on_child',
		// 	[
		// 		'label' => __( 'Apply on Child Element?', 'designer-powerup-for-elementor' ),
		// 		'type'  => \Elementor\Controls_Manager::SWITCHER,
		// 		'render_type'  => 'ui',
		// 	]
		// );

		// $element->add_control(
		// 	'edp_transform_apply_on_child_class',
		// 	[
		// 		'label'       => __( 'Child Selector', 'designer-powerup-for-elementor' ),
		// 		'type'        => \Elementor\Controls_Manager::TEXT,
		// 		'placeholder' => __( '.child-selector', 'designer-powerup-for-elementor' ),
		// 		'condition'   => [
		// 			'edp_transform_apply_on_child' => 'yes',
		// 		],
		// 		'render_type'  => 'ui',
		// 	]
		// );

		$element->add_control(
			'edp_transform_divider',
			[
				'type' => Controls_Manager::DIVIDER,
				'render_type' => 'none',
			]
		);

		$element->start_controls_tabs(
			'edp_transform_tabs'
		);

		$element->start_controls_tab(
			'edp_transform_normal_tab',
			[
				'label' => __('Normal', 'designer-powerup-for-elementor'),
			]
		);

		edp_transform_controls($element, $element_selector);

		$element->end_controls_tab();

		/**
		 * Transform Hover State
		 */

		$element->start_controls_tab(
			'edp_transform_hover_tab',
			[
				'label' => __('Hover', 'designer-powerup-for-elementor'),
			]
		);

		edp_transform_controls($element, $element_selector, 'hover');

		$element->end_controls_tab();

		$element->end_controls_tabs();

		/**
		 * Outputs the transform CSS when any one of the hover popover is active
		 */
		$element->add_control(
			'_edp_transform_css_output',
			[
				'label' => __('CSS Transform Output', 'designer-powerup-for-elementor'),
				'type' => Controls_Manager::HIDDEN,
				'default' => 'yes',
				'selectors' => [
					"{{WRAPPER}}{$element_selector}" => 'transform: rotateZ(var(--edp-transform-rotateZ, 0)) rotateX(var(--edp-transform-rotateX, 0)) rotateY(var(--edp-transform-rotateY, 0)) translateX(var(--edp-transform-translateX, 0)) translateY(var(--edp-transform-translateY, 0)) scale( var( --edp-transform-scale, 1), var( --edp-transform-scale, 1) ) skewX(var(--edp-transform-skewX, 0)) skewY(var(--edp-transform-skewY, 0));'
				],
				'conditions' => [
					'relation' => 'or',
					'terms' => [
						[
							'name' => 'edp_transform_normal_translate_toggle',
							'operator' => '!=',
							'value' => '',
						],
						[
							'name' => 'edp_transform_hover_translate_toggle',
							'operator' => '!=',
							'value' => '',
						],
						[
							'name' => 'edp_transform_normal_rotate_toggle',
							'operator' => '!=',
							'value' => '',
						],
						[
							'name' => 'edp_transform_hover_rotate_toggle',
							'operator' => '!=',
							'value' => '',
						],
						[
							'name' => 'edp_transform_normal_scale_toggle',
							'operator' => '!=',
							'value' => '',
						],
						[
							'name' => 'edp_transform_hover_scale_toggle',
							'operator' => '!=',
							'value' => '',
						],
						[
							'name' => 'edp_transform_normal_skew_toggle',
							'operator' => '!=',
							'value' => '',
						],
						[
							'name' => 'edp_transform_hover_skew_toggle',
							'operator' => '!=',
							'value' => '',
						],
					]
				],
			]
		);

		$element->end_controls_section();
	},
	10,
	2
);

/**
 * Transform controls
 *
 * @param Element_Base $element The Controls Stack.
 * @param string       $state The element state.
 *
 * @return void
 */
function edp_transform_controls($element, $element_selector, $state = 'normal') {

	$state_selector = ('normal' !== $state) ? ':hover' : '';

	$element->add_control(
		"edp_transform_{$state}_translate_toggle",
		[
			'label' => __('Move', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::POPOVER_TOGGLE,
			'render_type' => 'ui',

		]
	);

	$element->start_popover();

	$element->add_responsive_control(
		"edp_transform_{$state}_translate_x",
		[
			'label' => __('Horizontal', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::SLIDER,
			'size_units' => ['px'],
			'range' => [
				'px' => [
					'min' => -1000,
					'max' => 1000,
				],
			],
			'selectors' => [
				"{{WRAPPER}}{$element_selector}{$state_selector}" => '--edp-transform-translateX: {{SIZE}}{{UNIT}}',
			],
			'condition' => [
				"edp_transform_{$state}_translate_toggle!" => '',
			],
		]
	);

	$element->add_responsive_control(
		"edp_transform_{$state}_translate_y",
		[
			'label' => __('Vertical', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::SLIDER,
			'size_units' => ['px'],
			'range' => [
				'px' => [
					'min' => -1000,
					'max' => 1000,
				],
			],
			'selectors' => [
				"{{WRAPPER}}{$element_selector}{$state_selector}" => '--edp-transform-translateY: {{SIZE}}{{UNIT}}',
			],
			'condition' => [
				"edp_transform_{$state}_translate_toggle!" => '',
			],
		]
	);

	$element->end_popover();

	$element->add_control(
		"edp_transform_{$state}_rotate_toggle",
		[
			'label' => __('Rotate', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::POPOVER_TOGGLE,
			'render_type' => 'ui',
		]
	);

	$element->start_popover();

	$element->add_responsive_control(
		"edp_transform_{$state}_rotate_x",
		[
			'label' => __('Horizontal Axis', 'designer-powerup-for-elementor'),
			'type'  => Controls_Manager::SLIDER,
			'size_units' => ['deg'],
			'range' => [
				'px' => [
					'min'  => -360,
					'max'  => 360,
					'step' => 1,
				],
			],
			'selectors' => [
				"{{WRAPPER}}{$element_selector}{$state_selector}" => '--edp-transform-rotateX: {{SIZE}}deg',
			],
			'condition' => [
				"edp_transform_{$state}_rotate_toggle!" => '',
			],
		]
	);

	$element->add_responsive_control(
		"edp_transform_{$state}_rotate_y",
		[
			'label' => __('Vertical Axis', 'designer-powerup-for-elementor'),
			'type'  => Controls_Manager::SLIDER,
			'size_units' => ['deg'],
			'range' => [
				'px' => [
					'min'  => -360,
					'max'  => 360,
					'step' => 1,
				],
			],
			'selectors' => [
				"{{WRAPPER}}{$element_selector}{$state_selector}" => '--edp-transform-rotateY: {{SIZE}}deg',
			],
			'condition' => [
				"edp_transform_{$state}_rotate_toggle!" => '',
			],
		]
	);

	$element->add_responsive_control(
		"edp_transform_{$state}_rotate_z",
		[
			'label' => __('Z Axis', 'designer-powerup-for-elementor'),
			'type'  => Controls_Manager::SLIDER,
			'size_units' => ['deg'],
			'range' => [
				'px' => [
					'min'  => -360,
					'max'  => 360,
					'step' => 1,
				],
			],
			'selectors' => [
				"{{WRAPPER}}{$element_selector}{$state_selector}" => '--edp-transform-rotateZ: {{SIZE}}deg',
			],
			'condition' => [
				"edp_transform_{$state}_rotate_toggle!" => '',
			],
		]
	);

	$element->end_popover();

	$element->add_control(
		"edp_transform_{$state}_scale_toggle",
		[
			'label' => __('Scale', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::POPOVER_TOGGLE,
			'render_type' => 'ui',
		]
	);

	$element->start_popover();

	$element->add_responsive_control(
		"edp_transform_{$state}_scale",
		[
			'label' => __('Size', 'designer-powerup-for-elementor'),
			'type'  => Controls_Manager::SLIDER,
			'default' => [
				'unit' => 'px',
				'size' => 1,
			],
			'range' => [
				'px' => [
					'min'  => 0.1,
					'max'  => 5,
					'step' => 0.1,
				],
			],
			'selectors' => [
				"{{WRAPPER}}{$element_selector}{$state_selector}" => '--edp-transform-scale: {{SIZE}}',
			],
			'condition' => [
				"edp_transform_{$state}_scale_toggle!" => '',
			],
		]
	);

	$element->end_popover();

	$element->add_control(
		"edp_transform_{$state}_skew_toggle",
		[
			'label' => __('Skew', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::POPOVER_TOGGLE,
			'render_type' => 'ui',
		]
	);

	$element->start_popover();

	$element->add_responsive_control(
		"edp_transform_{$state}_skew_x",
		[
			'label' => __('Horizontal', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::SLIDER,
			'size_units' => ['px'],
			'range' => [
				'px' => [
					'min' => -90,
					'max' => 90,
				],
			],
			'selectors' => [
				"{{WRAPPER}}{$element_selector}{$state_selector}" => '--edp-transform-skewX: {{SIZE}}deg',
			],
			'condition' => [
				"edp_transform_{$state}_skew_toggle!" => '',
			],
		]
	);

	$element->add_responsive_control(
		"edp_transform_{$state}_skew_y",
		[
			'label' => __('Vertical', 'designer-powerup-for-elementor'),
			'type' => Controls_Manager::SLIDER,
			'size_units' => ['px'],
			'range' => [
				'px' => [
					'min' => -90,
					'max' => 90,
				],
			],
			'selectors' => [
				"{{WRAPPER}}{$element_selector}{$state_selector}" => '--edp-transform-skewY: {{SIZE}}deg',
			],
			'condition' => [
				"edp_transform_{$state}_skew_toggle!" => '',
			],
		]
	);

	$element->end_popover();
}
