<?php
/**
 * CSS Transition Controls.
 *
 * @package designer-powerup-for-elementor\powerups\transition
 */

use \Elementor\Controls_Manager;

add_action(
	'elementor/element/after_section_end',
	function( $element, $section_id ) {

		if ( '_section_responsive' !== $section_id ) {
			return;
		}

		$widget_selector = ( $element->get_type() == 'widget' ) ? ' > .elementor-widget-container' : '';

		$element->start_controls_section(
			'edp_transition_section',
			[
				'label' => __( 'State Transition', 'designer-powerup-for-elementor' ),
				'tab'   => 'edp',
			]
		);

		$element->add_control(
			'edp_add_transition',
			[
				'label'     => __( 'Apply transition?', 'designer-powerup-for-elementor' ),
				'type'      => Controls_Manager::SWITCHER,
				'selectors' => [
					'{{WRAPPER}}' . $widget_selector => 'transition-property: background, border-radius, box-shadow, opacity, transform, filter, text-shadow;',
				],
			]
		);

		$element->add_control(
			'edp_transition_duration',
			[
				'label' => __( 'Duration (s)', 'designer-powerup-for-elementor' ),
				'type'  => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max'  => 5,
						'step' => 0.1,
					],
				],
				'default' => [
					'unit' => 'px',
					'size' => 0.3,
				],
				'selectors' => [
					'{{WRAPPER}}' . $widget_selector => 'transition-duration: {{SIZE}}s',
				],
				'condition' => [
					'edp_add_transition' => 'yes',
				],
			]
		);

		$element->add_control(
			'edp_transition_timing_function',
			[
				'label'   => __( 'Timing Function', 'designer-powerup-for-elementor' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'ease',
				'options' => [
					'ease'        => __( 'Ease', 'designer-powerup-for-elementor' ),
					'linear'      => __( 'Linear', 'designer-powerup-for-elementor' ),
					'ease-in'     => __( 'Ease in', 'designer-powerup-for-elementor' ),
					'ease-out'    => __( 'Ease out', 'designer-powerup-for-elementor' ),
					'ease-in-out' => __( 'Ease-in-out', 'designer-powerup-for-elementor' ),
				],
				'condition' => [
					'edp_add_transition' => 'yes',
				],
			]
		);

		$element->add_control(
			'edp_transition_delay',
			[
				'label' => __( 'Delay (s)', 'designer-powerup-for-elementor' ),
				'type'  => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max'  => 3,
						'step' => 0.1,
					],
				],
				'selectors' => [
					'{{WRAPPER}}' . $widget_selector => 'transition-delay: {{SIZE}}s',
				],
				'condition' => [
					'edp_add_transition' => 'yes',
				],
			]
		);

		$element->end_controls_section();

	},
	10, 2
);
